@@ -5,10 +5,10 @@ use Moose::Exporter;
 
 use MooseX::UndefTolerant::Attribute;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 Moose::Exporter->setup_import_methods(
-    attribute_metaclass_roles => [ 'MooseX::UndefTolerant::Attribute' ]
+    class_metaroles => { attribute => [ 'MooseX::UndefTolerant::Attribute' ] }
 );
 
 1;
